Skip to contents

readRenameData() Reads in SurveyMonkey data with new variable names taken from the codebook tibble column named variable_name created by using the function createCodebook().

Usage

readRenameData(file_path, codebook)

Arguments

file_path

Required, A file path with extension of .csv or .xlsx.

codebook

Required, A tibble created by using the function createCodebook() that has the column named variable_name that will be the new names of the data imported into R.

Value

A tibble of SurveyMonkey data with new variable names.