Helper function to create qualitative colors from the Okabe-Ito palette.
Source: R/colorHelpers.R
qualFillColors.RdA function to create a custom qualitative colors palette from the Okabe-Ito palette, reversed if rev_colors is set to TRUE.
Drops black and yellow for use with all Blackstone charts and adds three other colors: "#440154FF", "#283251", and "#999933".
Examples
# Returns the full color palette:
qualFillColors()
#> [1] "#E69F00" "#56B4E9" "#009E73" "#CC79A7" "#D55E00" "#0072B2"
#> [7] "#440154FF" "#999999" "#117733" "#283251" "#999933"
# Returns the first 5 colors in the palette:
qualFillColors(n_colors = 5)
#> [1] "#E69F00" "#56B4E9" "#009E73" "#CC79A7" "#D55E00"
# Returns the first 5 colors in the palette reversed:
qualFillColors(n_colors = 5, rev_colors = TRUE)
#> [1] "#D55E00" "#CC79A7" "#009E73" "#56B4E9" "#E69F00"